@@ -1,7 +1,8 @@
 """MQTT Hass Base."""
 import logging
-import os
-from typing import List
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+import paho.mqtt.client as mqtt
 
 from mqtt_hass_base import entity as mqtt_entity
 from mqtt_hass_base.error import MQTTHassBaseError
@@ -19,49 +20,60 @@ ENTITY_TYPES = (
 class MqttDevice:
     """Mqtt device base class."""
 
-    def __init__(self, name: str, logger: logging.Logger):
+    _entities: List[mqtt_entity.MqttEntity] = []
+
+    def __init__(
+        self,
+        name: str,
+        logger: logging.Logger,
+        mqtt_discovery_root_topic: str,
+        mqtt_data_root_topic: str,
+    ):
         """Create a new device."""
         # Get logger
         self.logger = logger.getChild(name)
         self._name = name
-        self.mqtt_discovery_root_topic = os.environ.get(
-            "MQTT_DISCOVERY_ROOT_TOPIC", os.environ.get("ROOT_TOPIC", "homeassistant")
-        )
-        self.mqtt_data_root_topic = os.environ.get(
-            "MQTT_DATA_ROOT_TOPIC", "homeassistant"
-        )
-        self._entities = []
-        self._model = None
-        self._manufacturer = None
-        self._sw_version = None
-        self._via_device = None
-        self._identifiers = []
-        self._connections = []
-        self._mac = None
+        self.mqtt_discovery_root_topic = mqtt_discovery_root_topic
+        self.mqtt_data_root_topic = mqtt_data_root_topic
+        self._entities: List[mqtt_entity.MqttEntity] = []
+        self._model: Optional[str] = None
+        self._manufacturer: Optional[str] = None
+        self._sw_version: Optional[str] = None
+        self._via_device: Optional[str] = None
+        self._identifiers: List[str] = []
+        self._connections: Dict[str, str] = {}
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """Get repr of the current device."""
-        return "<{} '{}'>".format(self.__class__.__name__, self.name)
+        return f"<{self.__class__.__name__} '{self.name}'>"
 
     @property
-    def entities(self):
+    def entities(self) -> List[mqtt_entity.MqttEntity]:
         """Get the list of the entities of the devices."""
         return self._entities
 
     def add_entity(
         self,
-        entity_type,
-        name,
-        unique_id,
-        entity_settings,
-        subscriptions=None,
-        sub_mqtt_topic=None,
-    ):
+        entity_type: "str",
+        name: str,
+        unique_id: str,
+        entity_settings: Union[
+            mqtt_entity.BinarySensorSettingsType,
+            mqtt_entity.SensorSettingsType,
+            mqtt_entity.LightSettingsType,
+            mqtt_entity.LockSettingsType,
+            mqtt_entity.SwitchSettingsType,
+            mqtt_entity.VacuumSettingsType,
+        ],
+        subscriptions: Optional[dict[str, str]] = None,
+        sub_mqtt_topic: Optional[str] = None,
+    ) -> mqtt_entity.MqttEntity:
         """Add a new entity in the device."""
         if entity_type.lower() not in ENTITY_TYPES:
             msg = (
-                "Entity type '{}' is not supported. " "Supported types are: {}"
-            ).format(entity_type, ENTITY_TYPES)
+                f"Entity type '{entity_type}' is not supported. "
+                f"Supported types are: {ENTITY_TYPES}"
+            )
             self.logger.error(msg)
             raise MQTTHassBaseError(msg)
 
@@ -86,122 +98,129 @@ class MqttDevice:
         self._entities.append(ent)
         return ent
 
-    def set_mqtt_client(self, mqtt_client):
+    def set_mqtt_client(self, mqtt_client: mqtt.Client) -> None:
         """Set the mqtt client to each entity."""
         for entity in self.entities:
             entity.set_mqtt_client(mqtt_client)
 
-    def register(self):
+    def register(self) -> None:
         """Register all entities in MQTT."""
         self.logger.info("Registering entities for device %s", self.name)
         for entity in self.entities:
             entity.register()
 
-    def subscribe(self):
+    def subscribe(self) -> None:
         """Subscribe to the MQTT topic needed for each entity."""
         self.logger.info("Subscribing to input mqtt topics")
         for entity in self.entities:
             entity.subscribe()
 
-    def unregister(self):
+    def unregister(self) -> None:
         """Unregister all entities from MQTT."""
         self.logger.info("Unregistering entities for device %s", self.name)
         for entity in self.entities:
             entity.unregister()
 
     @property
-    def name(self):
+    def name(self) -> Optional[str]:
         """Return the name of the device."""
         return self._name
 
     @name.setter
-    def name(self, name: str):
+    def name(self, name: str) -> None:
         if name != self._name:
             self.logger = self.logger.getChild("device").getChild(name)
         self._name = name
 
     @property
-    def model(self):
+    def model(self) -> Optional[str]:
         """Return the module of the device."""
         return self._model
 
     @model.setter
-    def model(self, model: str):
+    def model(self, model: str) -> None:
         self._model = model
 
     @property
-    def manufacturer(self):
+    def manufacturer(self) -> Optional[str]:
         """Return the manufacturer of the device."""
         return self._manufacturer
 
     @manufacturer.setter
-    def manufacturer(self, manufacturer: str):
+    def manufacturer(self, manufacturer: str) -> None:
         self._manufacturer = manufacturer
 
     @property
-    def sw_version(self):
+    def sw_version(self) -> Optional[str]:
         """Return the software version of the device."""
         return self._sw_version
 
     @sw_version.setter
-    def sw_version(self, sw_version: str):
+    def sw_version(self, sw_version: str) -> None:
         self._sw_version = sw_version
 
     @property
-    def via_device(self):
+    def via_device(self) -> Optional[str]:
         """Return the intermediate device name of the current device."""
         return self._via_device
 
     @via_device.setter
-    def via_device(self, via_device: str):
+    def via_device(self, via_device: str) -> None:
         self._via_device = via_device
 
     @property
-    def identifiers(self):
+    def identifiers(self) -> List[str]:
         """Return the identifiers of the device."""
         return self._identifiers
 
     @identifiers.setter
-    def identifiers(self, id_: str):
+    def identifiers(self, ids: List[str]) -> None:
+        self._identifiers = ids
+
+    def add_identifier(self, id_: str) -> None:
+        """Add a new identifier to the current device."""
         if id_ not in self._identifiers:
             self._identifiers.append(id_)
 
     @property
-    def mac(self):
+    def mac(self) -> Optional[str]:
         """Return the mac address of the device."""
-        return self._mac
+        return self.connections.get("mac")
 
     @mac.setter
-    def mac(self, value):
-        self._mac = value
-        self.connections = ("mac", value)
+    def mac(self, value: str) -> None:
+        self.add_connections({"mac": value})
 
     @property
-    def connections(self):
+    def connections(self) -> Dict[str, str]:
         """Return the connection list of the device."""
         return self._connections
 
-    @connections.setter
-    def connections(self, raw_item: List[str]):
-        try:
-            item = list(raw_item)
-        except TypeError:
-            raise MQTTHassBaseError("Bad connection value: {}".format(raw_item))
-        if len(item) != 2:
+    def add_connections(self, raw_item: Union[Dict[str, str], Tuple[str, str]]) -> None:
+        """Add new connection(s) to the device config."""
+        if isinstance(raw_item, dict):
+            self._connections.update(raw_item)
+        elif isinstance(raw_item, tuple):
+            if len(raw_item) != 2:
+                raise MQTTHassBaseError(
+                    f"A connection needs 2 elements but it's: {raw_item}"
+                )
+            self._connections[raw_item[0]] = raw_item[1]
+        else:
             raise MQTTHassBaseError(
-                "A connection need 2 elements but it's: {}".format(raw_item)
+                f"Bad connection value: {raw_item} - Shoube dict or tuple"
             )
-        if item not in self._connections:
-            self._connections.append(item)
 
     @property
-    def config_device_payload(self):
+    def config_device_payload(self) -> dict[str, Any]:
         """Return the configuration device payload.
 
         This is the payload needed to register an entity of the current
         device in Home Assistant (using MQTT discovery).
         """
-        payload = {"name": self.name}
+        payload: Dict[str, Union[Optional[str], List[str], Dict[str, str]]] = {
+            "name": self.name
+        }
         if self.connections:
             payload["connections"] = self.connections
         if self.identifiers:
