@@ -1,39 +1,60 @@
 """MQTT Light entity module."""
 import json
-from typing import Dict, List
+import logging
+from typing import Any, Dict, List, Optional, Union
 
-from mqtt_hass_base.entity.common import MqttEntity
+from mqtt_hass_base.entity.common import EntitySettingsType, MqttEntity
+
+
+class LightSettingsType(EntitySettingsType, total=False):
+    """Light entity settings dict format."""
+
+    optimistic: bool
+    brightness: bool
+    brightness_scale: int
+    color_temp: bool
+    effect: bool
+    effect_list: Optional[List[str]]
+    flash_time_long: Optional[int]
+    flash_time_short: Optional[int]
+    hs_: bool
+    max_mireds: Optional[int]
+    min_mireds: Optional[int]
+    rgb: bool
+    white_value: bool
+    xy_: bool
 
 
 class MqttLight(MqttEntity):
     """MQTT Light entity class."""
 
     _component = "light"
+    _effect_list: List[str] = []
 
     def __init__(  # pylint: disable=too-many-arguments
         self,
-        name,
+        name: str,
         unique_id: str,
         mqtt_discovery_root_topic: str,
         mqtt_data_root_topic: str,
-        logger,
-        device_payload,
-        subscriptions,
+        logger: logging.Logger,
+        device_payload: Dict[str, str],
+        subscriptions: Dict[str, str],
         optimistic: bool,
         brightness: bool = False,
         brightness_scale: int = 255,
         color_temp: bool = False,
         effect: bool = False,
-        effect_list: List = None,
-        flash_time_long: int = None,
-        flash_time_short: int = None,
+        effect_list: Optional[List[str]] = None,
+        flash_time_long: Optional[int] = None,
+        flash_time_short: Optional[int] = None,
         hs_: bool = False,
-        max_mireds: int = None,
-        min_mireds: int = None,
+        max_mireds: Optional[int] = None,
+        min_mireds: Optional[int] = None,
         rgb: bool = False,
         white_value: bool = False,
         xy_: bool = False,
-        object_id: str = None,
+        object_id: Optional[str] = None,
     ):
         """Create a new MQTT sensor entity object."""
         MqttEntity.__init__(
@@ -51,7 +72,8 @@ class MqttLight(MqttEntity):
         self._brightness_scale = brightness_scale
         self._color_temp = color_temp
         self._effect = effect
-        self._effect_list = effect_list
+        if effect_list:
+            self._effect_list = effect_list
         self._flash_time_long = flash_time_long
         self._flash_time_short = flash_time_short
         self._hs = hs_
@@ -62,7 +84,7 @@ class MqttLight(MqttEntity):
         self._white_value = white_value
         self._xy = xy_
 
-    def register(self):
+    def register(self) -> None:
         """Register the current entity to Hass.
 
         Using the MQTT discovery feature of Home Assistant.
@@ -114,9 +136,15 @@ class MqttLight(MqttEntity):
             topic=self.config_topic, retain=True, payload=json.dumps(config_payload)
         )
 
-    def send_state(self, state: Dict, attributes: Dict = None):
+    def send_state(
+        self,
+        state: Union[str, bytes, float, int],
+        attributes: Optional[Dict[str, Any]] = None,
+    ) -> None:
         """Send the current state of the light to Home Assistant."""
         # TODO validate the state dict
         self._mqtt_client.publish(
             topic=self.state_topic, retain=True, payload=json.dumps(state)
         )
+        if attributes is not None:
+            self.send_attributes(attributes)
