@@ -1,7 +1,9 @@
 """MQTT Lock entity module."""
 import json
+import logging
+from typing import Any, Dict, Optional, Union
 
-from mqtt_hass_base.entity.common import MqttEntity
+from mqtt_hass_base.entity.common import EntitySettingsType, MqttEntity
 from mqtt_hass_base.error import MQTTHassBaseError
 
 LOCK_STATES = {
@@ -16,6 +18,13 @@ LOCK_STATES = {
 }
 
 
+class LockSettingsType(EntitySettingsType, total=False):
+    """Lock entity settings dict format."""
+
+    icon: str
+    optimistic: bool
+
+
 class MqttLock(MqttEntity):
     """MQTT Lock entity class."""
 
@@ -23,16 +32,16 @@ class MqttLock(MqttEntity):
 
     def __init__(
         self,
-        name,
+        name: str,
         unique_id: str,
         mqtt_discovery_root_topic: str,
         mqtt_data_root_topic: str,
-        logger,
-        device_payload,
-        subscriptions,
+        logger: logging.Logger,
+        device_payload: Dict[str, str],
+        subscriptions: Dict[str, str],
         icon: str,
         optimistic: bool,
-        object_id: str = None,
+        object_id: Optional[str] = None,
     ):
         """Create a new MQTT sensor entity object."""
         MqttEntity.__init__(
@@ -49,7 +58,7 @@ class MqttLock(MqttEntity):
         self._icon = icon
         self._optimistic = optimistic
 
-    def register(self):
+    def register(self) -> None:
         """Register the current entity to Hass.
 
         Using the MQTT discovery feature of Home Assistant.
@@ -86,19 +95,25 @@ class MqttLock(MqttEntity):
             topic=self.config_topic, retain=True, payload=json.dumps(config_payload)
         )
 
-    def send_state(self, state, attributes=None):
+    def send_state(
+        self,
+        state: Union[str, bytes, float, int],
+        attributes: Optional[Dict[str, Any]] = None,
+    ) -> None:
         """Send the current state of the switch to Home Assistant."""
         if state not in LOCK_STATES:
-            msg = "Bad lock state {} . Should be in {}".format(state, LOCK_STATES)
+            msg = f"Bad lock state {state!s}. Should be in {LOCK_STATES}"
             self.logger.error(msg)
             raise MQTTHassBaseError(msg)
-        payload = LOCK_STATES.get(state)
+        payload = LOCK_STATES.get(str(state))
         self._mqtt_client.publish(topic=self.state_topic, retain=True, payload=payload)
+        if attributes is not None:
+            self.send_attributes(attributes)
 
-    def send_locked(self, attributes=None):
+    def send_locked(self, attributes: Optional[Dict[str, Any]] = None) -> None:
         """Send the LOCKED state of the switch to Home Assistant."""
         self.send_state("LOCKED", attributes=attributes)
 
-    def send_unlocked(self, attributes=None):
+    def send_unlocked(self, attributes: Optional[Dict[str, Any]] = None) -> None:
         """Send the UNLOCKED state of the switch to Home Assistant."""
         self.send_state("UNLOCKED", attributes=attributes)
