@@ -1,7 +1,9 @@
 """MQTT Switch entity module."""
 import json
+import logging
+from typing import Any, Dict, Optional, Union
 
-from mqtt_hass_base.entity.common import MqttEntity
+from mqtt_hass_base.entity.common import EntitySettingsType, MqttEntity
 from mqtt_hass_base.error import MQTTHassBaseError
 
 SWITCH_STATES = {
@@ -17,6 +19,13 @@ SWITCH_STATES = {
 }
 
 
+class SwitchSettingsType(EntitySettingsType, total=False):
+    """Switch entity settings dict format."""
+
+    icon: str
+    optimistic: bool
+
+
 class MqttSwitch(MqttEntity):
     """MQTT Switch entity class."""
 
@@ -24,16 +33,16 @@ class MqttSwitch(MqttEntity):
 
     def __init__(
         self,
-        name,
+        name: str,
         unique_id: str,
         mqtt_discovery_root_topic: str,
         mqtt_data_root_topic: str,
-        logger,
-        device_payload,
-        subscriptions,
+        logger: logging.Logger,
+        device_payload: Dict[str, str],
+        subscriptions: Dict[str, str],
         icon: str,
         optimistic: bool,
-        object_id: str = None,
+        object_id: Optional[str] = None,
     ):
         """Create a new MQTT sensor entity object."""
         MqttEntity.__init__(
@@ -50,7 +59,7 @@ class MqttSwitch(MqttEntity):
         self._icon = icon
         self._optimistic = optimistic
 
-    def register(self):
+    def register(self) -> None:
         """Register the current entity to Hass.
 
         Using the MQTT discovery feature of Home Assistant.
@@ -85,19 +94,25 @@ class MqttSwitch(MqttEntity):
             topic=self.config_topic, retain=True, payload=json.dumps(config_payload)
         )
 
-    def send_state(self, state, attributes=None):
+    def send_state(
+        self,
+        state: Union[str, bytes, float, int],
+        attributes: Optional[Dict[str, Any]] = None,
+    ) -> None:
         """Send the current state of the switch to Home Assistant."""
         if state not in SWITCH_STATES:
-            msg = "Bad switch state {} . Should be in {}".format(state, SWITCH_STATES)
+            msg = f"Bad switch state {state!s}. Should be in {SWITCH_STATES}"
             self.logger.error(msg)
             raise MQTTHassBaseError(msg)
         payload = SWITCH_STATES.get(state)
         self._mqtt_client.publish(topic=self.state_topic, retain=True, payload=payload)
+        if attributes is not None:
+            self.send_attributes(attributes)
 
-    def send_on(self, attributes=None):
+    def send_on(self, attributes: Optional[Dict[str, Any]] = None) -> None:
         """Send the ON state of the switch to Home Assistant."""
         self.send_state("ON", attributes=attributes)
 
-    def send_off(self, attributes=None):
+    def send_off(self, attributes: Optional[Dict[str, Any]] = None) -> None:
         """Send the OFF state of the switch to Home Assistant."""
         self.send_state("OFF", attributes=attributes)
